@@ -203,7 +203,7 @@ class DownloadInfoFrame:
             panel = wxPanel(frame, -1)
             self.bgcolor = panel.GetBackgroundColour()
 
-            def StaticText(text, font = self.FONT, underline = False, color = None, panel = panel):
+            def StaticText(text, font = self.FONT-1, underline = False, color = None, panel = panel):
                 x = wxStaticText(panel, -1, text, style = wxALIGN_LEFT)
                 x.SetFont(wxFont(font, wxDEFAULT, wxNORMAL, wxNORMAL, underline))
                 if color is not None:
@@ -353,7 +353,7 @@ class DownloadInfoFrame:
 
             self.connChoiceLabel = StaticText('Settings for ')
             slideSizer.Add (self.connChoiceLabel, 0, wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL)
-            self.connChoice = wxChoice (panel, -1, (-1, -1), (self.FONT*11, -1),
+            self.connChoice = wxChoice (panel, -1, (-1, -1), (self.FONT*12, -1),
                                         choices = connChoiceList)
             self.connChoice.SetFont(self.default_font)
             self.connChoice.SetSelection(0)
@@ -440,7 +440,7 @@ class DownloadInfoFrame:
             self.frame.Fit()
             self.panel = panel
             self.border = border
-            self.addwidth = aboutText.GetBestSize().GetWidth() + fileDetails.GetBestSize().GetWidth() + (self.FONT*14)
+            self.addwidth = aboutText.GetBestSize().GetWidth() + fileDetails.GetBestSize().GetWidth() + (self.FONT*16)
             self.fnsizer = fnsizer
             self.colSizer = colSizer
             minsize = self.colSizer.GetSize()
@@ -757,7 +757,7 @@ class DownloadInfoFrame:
 
             si = ( 'exact Version String: ' + version + '\n' +
                    'Python version: ' + sys.version + '\n' +
-                   'wxWindows version: ' + wxVERSION_STRING + '\n' )
+                   'wxPython version: ' + wxVERSION_STRING + '\n' )
             try:
                 si += 'Psyco version: ' + hex(psyco.__version__)[2:] + '\n'
             except:
@@ -803,16 +803,17 @@ class DownloadInfoFrame:
             EVT_LEFT_DOWN(babble6, licenselink)
             EVT_LEFT_DOWN(credits, self.credits)
 
-            def closeAbout(self, frame = self):
-                frame.aboutBox.Close ()
+            def closeAbout(e, self = self):
+                if self.aboutBox:
+                    self.aboutBox.Close()
             EVT_BUTTON(self.aboutBox, okButton.GetId(), closeAbout)
-            def kill(self, frame = self):
+            def kill(e, self = self):
                 try:
-                    frame.RemoveIcon()
+                    self.aboutBox.RemoveIcon()
                 except:
                     pass
-                frame.aboutBox.Destroy()
-                frame.aboutBox = None
+                self.aboutBox.Destroy()
+                self.aboutBox = None
             EVT_CLOSE(self.aboutBox, kill)
 
             self.aboutBox.Show()
@@ -840,10 +841,11 @@ class DownloadInfoFrame:
             info = metainfo['info']
             info_hash = self.dow.infohash
             piece_length = info['piece length']
+            fileselector = self.dow.fileselector
 
             if (self.detailBox is not None):
                 try:
-                    self.detailBox.Close ()
+                    self.detailBox.Close()
                 except wxPyDeadObjectError, e:
                     self.detailBox = None
 
@@ -856,7 +858,7 @@ class DownloadInfoFrame:
 
             panel = wxPanel(self.detailBox, -1, size = wxSize (400,220))
 
-            def StaticText(text, font = self.FONT, underline = False, color = None, panel = panel):
+            def StaticText(text, font = self.FONT-1, underline = False, color = None, panel = panel):
                 x = wxStaticText(panel, -1, text, style = wxALIGN_CENTER_VERTICAL)
                 x.SetFont(wxFont(font, wxDEFAULT, wxNORMAL, wxNORMAL, underline))
                 if color is not None:
@@ -928,10 +930,11 @@ class DownloadInfoFrame:
                     fileList.SetStringItem(x, 0, path)
                     if file.has_key('md5sum'):
                         fileList.SetStringItem(x, 2, '    [' + str(file['md5sum']) + ']')
-                    p = self.dow.fileselector[x]
-                    item = self.fileList.GetItem(x)
-                    item.SetTextColour(self.prioritycolors[p+1])
-                    fileList.SetItem(item)
+                    if fileselector:
+                        p = fileselector[x]
+                        item = self.fileList.GetItem(x)
+                        item.SetTextColour(self.prioritycolors[p+1])
+                        fileList.SetItem(item)
                     x += 1
                     file_length += file['length']
                 fileList.SetColumnWidth(0,wxLIST_AUTOSIZE)
@@ -1024,7 +1027,7 @@ class DownloadInfoFrame:
             panel.SetSizer(border)
             panel.SetAutoLayout(True)
 
-            if fileListID:
+            if fileselector and fileListID:
                 def onRightClick(evt, self = self):
                     s = []
                     i = -1
@@ -1046,7 +1049,7 @@ class DownloadInfoFrame:
                     menu.Append(self.priorityIDs[1], "download first", kind=kind)
                     menu.Append(self.priorityIDs[2], "download normally", kind=kind)
                     menu.Append(self.priorityIDs[3], "download later", kind=kind)
-                    menu.Append(self.priorityIDs[0], "download never", kind=kind)
+                    menu.Append(self.priorityIDs[0], "download never (deletes)", kind=kind)
                     if oldstate is not None:
                         menu.Check(self.priorityIDs[oldstate+1], True)
 
@@ -1073,7 +1076,8 @@ class DownloadInfoFrame:
                 EVT_LIST_ITEM_RIGHT_CLICK(self.detailBox, fileListID, onRightClick)
 
             def closeDetail(evt, self = self):
-                self.detailBox.Close ()
+                if self.detailBox:
+                    self.detailBox.Close()
             EVT_BUTTON(self.detailBox, okButton.GetId(), closeDetail)
             def kill(evt, self = self):
                 try:
@@ -1184,16 +1188,17 @@ class DownloadInfoFrame:
             panel.SetSizer(border)
             panel.SetAutoLayout(True)
 
-            def closeCredits(self, frame = self):
-                frame.creditsBox.Close()
+            def closeCredits(e, self = self):
+                if self.creditsBox:
+                    self.creditsBox.Close()
             EVT_BUTTON(self.creditsBox, okButton.GetId(), closeCredits)
-            def kill(self, frame = self):
+            def kill(e, self = self):
                 try:
-                    frame.creditsBox.RemoveIcon()
+                    self.creditsBox.RemoveIcon()
                 except:
                     pass
-                frame.creditsBox.Destroy()
-                frame.creditsBox = None
+                self.creditsBox.Destroy()
+                self.creditsBox = None
             EVT_CLOSE(self.creditsBox, kill)
 
             self.creditsBox.Show()
@@ -1330,7 +1335,7 @@ class DownloadInfoFrame:
 
             panel = wxPanel(self.advBox, -1, size = wxSize (200,200))
 
-            def StaticText(text, font = self.FONT, underline = False, color = None, panel = panel):
+            def StaticText(text, font = self.FONT-1, underline = False, color = None, panel = panel):
                 x = wxStaticText(panel, -1, text, style = wxALIGN_LEFT)
                 x.SetFont(wxFont(font, wxDEFAULT, wxNORMAL, wxNORMAL, underline))
                 if color is not None:
@@ -1625,11 +1630,10 @@ class DownloadInfoFrame:
                     self.rateSpinner.SetValue(newValue)
 
         if self.fin:
-            if statistics is not None:
-                if statistics.numOldSeeds > 0 or statistics.numCopies > 1:
-                    self.gauge.SetValue(1000)
-                else:
-                    self.gauge.SetValue(int(1000*statistics.numCopies))
+            if statistics is None or statistics.numOldSeeds > 0 or statistics.numCopies > 1:
+                self.gauge.SetValue(1000)
+            else:
+                self.gauge.SetValue(int(1000*statistics.numCopies))
         elif self.gui_fractiondone is not None:
             gaugelevel = int(self.gui_fractiondone * 1000)
             self.gauge.SetValue(gaugelevel)
@@ -1664,7 +1668,7 @@ class DownloadInfoFrame:
                 icontext=icontext+' d:%.0f kB/s' % (float(downRate) / 1000)
             icontext+=' %s' % self.filename
             try:
-                if self.fin:
+                if self.gui_fractiondone == None or self.gui_fractiondone == 1.0:
                     self.frame.tbicon.SetIcon(self.finicon,icontext)
                 else:
                     self.frame.tbicon.SetIcon(self.icon,icontext)
@@ -2083,46 +2087,52 @@ class DownloadInfoFrame:
         self.uiflag.set()
         self.flag.set()
         self.shuttingdown = True
-        if self.taskbaricon:
-            self.frame.tbicon.RemoveIcon()
-            try:
-                self.frame.tbicon.Destroy()
-            except:
-                pass
-        if (self.detailBox is not None):
-            try:
-                self.detailBox.Close ()
-            except wxPyDeadObjectError, e:
-                self.detailBox = None
-        if (self.aboutBox is not None):
-            try:
-                self.aboutBox.Close ()
-            except wxPyDeadObjectError, e:
-                self.aboutBox = None
-        if (self.creditsBox is not None):
-            try:
-                self.creditsBox.Close ()
-            except wxPyDeadObjectError, e:
-                self.creditsBox = None
-        if (self.advBox is not None):
-            try:
-                self.advBox.Close ()
-            except wxPyDeadObjectError, e:
-                self.advBox = None
 
-        if (self.statusIconHelpBox is not None):
-            try:
-                self.statusIconHelpBox.Close ()
-            except wxPyDeadObjectError, e:
-                self.statusIconHelpBox = None
-        self.configfile.Close()
+        try:
+            self.frame.tbicon.RemoveIcon()
+        except:
+            pass
+        try:
+            self.frame.tbicon.Destroy()
+        except:
+            pass
+        try:
+            self.detailBox.Close()
+        except:
+            self.detailBox = None
+        try:
+            self.aboutBox.Close()
+        except:
+            self.aboutBox = None
+        try:
+            self.creditsBox.Close()
+        except:
+            self.creditsBox = None
+        try:
+            self.advBox.Close()
+        except:
+            self.advBox = None
+        try:
+            self.statusIconHelpBox.Close()
+        except:
+            self.statusIconHelpBox = None
         try:
             self.frame.RemoveIcon()
         except:
             pass
+
         self.frame.Destroy()
-        self.icon.Destroy()
-        self.finicon.Destroy()
+
+        wxver = wxVERSION_STRING.split(' ')[0].split('.')
+        if int(wxver[0]) >= 2 and int(wxver[1]) >= 6:
+            try:
+                self.icon.Destroy()
+            except:
+                pass
+            try:
+                self.finicon.Destroy()
+            except:
+                pass
 
     def exception(self):
         data = StringIO()
